==> openflowplugin-extension-nicira-0.5.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/copy/field/into/field/_case/FlowModCopyFieldIntoField.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 * <p>This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-copy-field-into-field {
 *     leaf flow-mod-num-bits {
 *         type uint16;
 *     }
 *     leaf src-field {
 *         type uint32;
 *     }
 *     leaf src-ofs {
 *         type uint16;
 *     }
 *     leaf dst-field {
 *         type uint32;
 *     }
 *     leaf dst-ofs {
 *         type uint16;
 *     }
 * }
 * </pre>
 * The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-field-into-field-case/flow-mod-copy-field-into-field</i>
 *
 * <p>To create instances of this class use {@link org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoFieldBuilder}.
 * @see org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoFieldBuilder
 *
 */
public interface FlowModCopyFieldIntoField
    extends
    ChildOf<FlowModSpec>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoField>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "flow-mod-copy-field-into-field").intern();

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    java.lang.Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Long</code> <code>srcField</code>, or <code>null</code> if not present
     */
    java.lang.Long getSrcField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    java.lang.Integer getSrcOfs();
    
    /**
     * @return <code>java.lang.Long</code> <code>dstField</code>, or <code>null</code> if not present
     */
    java.lang.Long getDstField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>dstOfs</code>, or <code>null</code> if not present
     */
    java.lang.Integer getDstOfs();

}

==> openflowplugin-extension-nicira-0.6.4-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/copy/field/into/field/_case/FlowModCopyFieldIntoField.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.binding.Augmentable;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-copy-field-into-field {
 *     leaf flow-mod-num-bits {
 *         type uint16;
 *     }
 *     leaf src-field {
 *         type uint32;
 *     }
 *     leaf src-ofs {
 *         type uint16;
 *     }
 *     leaf dst-field {
 *         type uint32;
 *     }
 *     leaf dst-ofs {
 *         type uint16;
 *     }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-field-into-field-case/flow-mod-copy-field-into-field</i>
 *
 * <p>To create instances of this class use {@link FlowModCopyFieldIntoFieldBuilder}.
 * @see FlowModCopyFieldIntoFieldBuilder
 *
 */
public interface FlowModCopyFieldIntoField
    extends
    ChildOf<FlowModSpec>,
    Augmentable<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.field.into.field._case.FlowModCopyFieldIntoField>
{



    public static final QName QNAME = org.opendaylight.yangtools.yang.common.QName.create("urn:opendaylight:openflowplugin:extension:nicira:action",
        "2014-07-14", "flow-mod-copy-field-into-field").intern();

    /**
     * @return <code>java.lang.Integer</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    java.lang.Integer getFlowModNumBits();
    
    /**
     * @return <code>java.lang.Long</code> <code>srcField</code>, or <code>null</code> if not present
     */
    java.lang.Long getSrcField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    java.lang.Integer getSrcOfs();
    
    /**
     * @return <code>java.lang.Long</code> <code>dstField</code>, or <code>null</code> if not present
     */
    java.lang.Long getDstField();
    
    /**
     * @return <code>java.lang.Integer</code> <code>dstOfs</code>, or <code>null</code> if not present
     */
    java.lang.Integer getDstOfs();

}
